@@ -40,6 +40,7 @@ import pynotify
 import dbus
 import location
 
+
 class account():
 
 
@@ -79,15 +80,17 @@ class account():
         self.controller = controller
         #these store all the data associated with this accounts tweets
         # the fields are : Name,sender_id,Tweet,TweetColour,id, type, timestamp, replyTo, source, pic, formatted_tweet
-        self.tweetstore = gtk.ListStore(str, str, str, str, float, str, str , str, str, gtk.gdk.Pixbuf, str)
+        self.tweetstore = gtk.ListStore(str, str, str, str, float, str, str , str, str, gtk.gdk.Pixbuf, str,bool)
+        self.filteredtweetstore = gtk.ListStore(str, str, str, str, float, str, str , str, str, gtk.gdk.Pixbuf, str,bool)
+        
         #then we want the same again to store dm's, mentions & pubilc timeline separately
-        self.dmstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.mentionstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.publicstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.trendstore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.friendsstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.searchstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.userhistorystore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str)
+        self.dmstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str,bool)
+        self.mentionstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str,bool)
+        self.publicstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str,bool)
+        self.trendstore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str,bool)
+        self.friendsstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str,bool)
+        self.searchstore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str,bool)
+        self.userhistorystore = gtk.ListStore(str, str, str, str, float, str, str, str, str, gtk.gdk.Pixbuf, str,bool)
         #store of avatar, filename, access count
         self.avatars = gtk.ListStore(gtk.gdk.Pixbuf, str, int, str)
         #base url can be set to any twitter compatible site, so we can support mutliple account types
@@ -174,6 +177,7 @@ class account():
             #self.controller.ui.profileImage.set_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + str(user.id)+".jpg")
             self.controller.ui.profileImage.set_from_pixbuf(avatar)  
             self.getSavedSearches()
+            self.getLists()
         except AttributeError, ae:
             print "Failed to load profile info" 
             print ae
@@ -330,7 +334,7 @@ class account():
                          formatted_ts = self.format_timestamp(created_at)
                          formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to, loc=place)
                          longid= long(x.id)
-                         self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", longid, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                         self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", longid, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
                          
                          receive_count = receive_count + 1
 
@@ -421,7 +425,7 @@ class account():
                      created_at = self.parse_time(x.created_at)
                      formatted_ts = self.format_timestamp(created_at)
                      formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
-                     self.mentionstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                     self.mentionstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
                      receive_count = receive_count + 1
 
             if (receive_count > 0):
@@ -515,7 +519,7 @@ class account():
                      created_at = self.parse_time(x.created_at)
                      formatted_ts = self.format_timestamp(created_at)
                      formatted_tweet = self.format_tweet(user, text, formatted_ts, None, None)
-                     self.dmstore.append([ "@" + user, x.GetSenderId(), "@" + user + " : " + text, "", long(x.id), "Tweet", x.created_at, "", "", pic, formatted_tweet])
+                     self.dmstore.append([ "@" + user, x.GetSenderId(), "@" + user + " : " + text, "", long(x.id), "Tweet", x.created_at, "", "", pic, formatted_tweet, True])
                      receive_count = receive_count + 1
 
             if (receive_count > 0):
@@ -595,7 +599,7 @@ class account():
                         created_at = self.parse_time(tweettime)
                         formatted_ts = self.format_timestamp(created_at)
                         formatted_tweet = self.format_tweet(x.screen_name, status, formatted_ts, source, None)
-                        self.friendsstore.append([ "@" + x.screen_name, str(x.id), "@" + x.screen_name + " : " + status, "", long(x.id), "friend", tweettime, "", source, pic, formatted_tweet])
+                        self.friendsstore.append([ "@" + x.screen_name, str(x.id), "@" + x.screen_name + " : " + status, "", long(x.id), "friend", tweettime, "", source, pic, formatted_tweet, True])
                         receive_count = receive_count + 1
     
                     if (receive_count > 0):
@@ -686,7 +690,7 @@ class account():
                      created_at = self.parse_time(x.created_at)
                      formatted_ts = self.format_timestamp(created_at)
                      formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
-                     self.publicstore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                     self.publicstore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
                      receive_count = receive_count + 1
 
             if (receive_count > 0):
@@ -749,7 +753,7 @@ class account():
                      created_at = self.parse_time(x.created_at)
                      formatted_ts = self.format_timestamp(created_at)
                      formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
-                     self.userhistorystore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                     self.userhistorystore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
                      receive_count = receive_count + 1
 
                      if (receive_count > 0):
@@ -836,7 +840,7 @@ class account():
                         created_at = self.parse_time(x['created_at'])
                         formatted_ts = self.format_timestamp(created_at)
                         formatted_tweet = self.format_tweet(x['from_user'], text, formatted_ts, source, reply_to)
-                        self.searchstore.append([ "@" + x['from_user'], str(x['from_user_id']), "@" + x['from_user'] + " : " + text, "", long(x['id']), "Search", x['created_at'], reply_to, source, pic, formatted_tweet])
+                        self.searchstore.append([ "@" + x['from_user'], str(x['from_user_id']), "@" + x['from_user'] + " : " + text, "", long(x['id']), "Search", x['created_at'], reply_to, source, pic, formatted_tweet, True])
                         receive_count = receive_count + 1
                         note = osso.SystemNote(self.osso_c)
                         result = note.system_note_infoprint("Search results Received for : " + term)
@@ -867,6 +871,43 @@ class account():
                     note = osso.SystemNote(self.osso_c)
                     note.system_note_dialog("Network error occured. Please try again")
 
+    def getLists(self, *args):
+        try:
+            listdata = self.api.GetLists(self.accountdata.username)
+            print listdata
+            lists = listdata['lists']
+            for list in lists:
+                print list['id']
+                print list['name']
+                print list['member_count']
+                membersData = self.api.GetListMembers(self.accountdata.username, list['id'])
+                #print listMembers
+                listMembers = membersData['users']
+                for user in listMembers:
+                    #print user
+                    print user['screen_name']
+        except IOError, e:
+            msg = 'Error retrieving lists and members results '
+            if hasattr(e, 'reason'):
+                msg = msg + str(e.reason)
+
+            if hasattr(e, 'code'):
+                if (e.code == 401):
+                    reason = "Not authorised: check uid/pwd"
+                elif(e.code == 503):
+                    reason = "Service unavailable"
+                else:
+                    reason = ""
+                msg = msg + 'Server returned ' + str(e.code) + " : " + reason
+            note = osso.SystemNote(self.osso_c)
+            note.system_note_dialog(msg)
+        except httplib.BadStatusLine:
+            print "Network error - BadStatusLine"
+            note = osso.SystemNote(self.osso_c)
+            note.system_note_dialog("Network error occured. Please try again")
+        
+            
+
     def getSavedSearches(self, * args):
         print "getting saved search terms"
         #self.searchstore.clear()
@@ -1105,7 +1146,7 @@ class account():
                     created_at = self.parse_time(x.created_at)
                     formatted_ts = self.format_timestamp(created_at)
                     formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
-                    self.tweetstore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                    self.tweetstore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet, True])
                 #update follower count
                 self.setProfileInfo()
         except IOError, e:
@@ -1441,8 +1482,44 @@ class account():
             if (long(entryId) == id):
                 return True
             item = store.iter_next(item)
-        return False    
+        return False  
+    
+    def filterTweets(self, sourceList, filter):   
+        temptweetstore = sourceList
+        item = temptweetstore.get_iter_first()
         
+        while item != None:
+            tweet = sourceList.get_value(item, 2)
+            tweet = tweet.lower()
+            filter = filter.lower()
+            if (tweet.find(filter) != -1):
+                print "filtering " + tweet
+                temptweetstore.set_value(item,11,False)
+            item = temptweetstore.iter_next(item)
+        return temptweetstore
+    
+    def unfilterTweets(self, sourceList, filter):   
+        temptweetstore = sourceList
+        item = temptweetstore.get_iter_first()
+        
+        while item != None:
+            tweet = sourceList.get_value(item, 2)
+            if (tweet.find(filter) != -1):
+                print "filtering " + tweet
+                temptweetstore.set_value(item,11,True)
+            item = temptweetstore.iter_next(item)
+        return temptweetstore
+    
+    def unfilterAllTweets(self, sourceList):   
+        temptweetstore = sourceList
+        item = temptweetstore.get_iter_first()
+        
+        while item != None:
+            tweet = sourceList.get_value(item, 2)
+            temptweetstore.set_value(item,11,True)
+            item = temptweetstore.iter_next(item)
+        return temptweetstore
+    
     def on_error(self,control, error, data):
         print "location error: %d... quitting" % error
         data.quit()
