@@ -99,6 +99,7 @@ class Witter():
         self.publicrefresh = None
         self.searchrefresh = None
         self.search_clear = False
+        self.filterList = []
         self.username = "UserName"
         self.password = ""
         self.bitlyusername = ""
@@ -485,6 +486,17 @@ class Witter():
     		    print "No refresh_interval section"
             except ConfigParser.NoOptionError:
                 print "unknown option"
+            try:
+                counter=0
+                while True:
+                    self.filterList.append(config.get("filters", "filter"+str(counter)))
+                    counter = counter+1
+                
+                
+            except ConfigParser.NoSectionError:
+                print "No filters section"
+            except ConfigParser.NoOptionError:
+                print "unknown option"
             try:
                 f = open('/home/user/.witteroauth')
                 self.access_token = pickle.load(f)
@@ -601,6 +613,11 @@ class Witter():
                 f.write("search_clear = True\n")
             else:
                 f.write("search_clear = False\n")
+            f.write("[filters]\n")
+            counter=0
+            for filter in self.filterList:
+                f.write("filter"+str(counter)+" = " + filter+"\n")
+                counter = counter+1
     	except IOError, e:
     		print "failed to write config file"
         try:
@@ -630,7 +647,8 @@ class Witter():
                 f3.write("last_mention_id" + str(counter) + " = " + str(account.last_mention_id) + "\n")
 
                 counter = counter + 1
-
+            
+            
             print "written config object to file"
         except IOError, e:
             print "failed to write ConfigObject"
@@ -708,7 +726,7 @@ class Witter():
                 else:
                     avatar = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
                 avatar = avatar.scale_simple(60, 60, gtk.gdk.INTERP_BILINEAR)
-                tweetstore.append([senderName,senderId,tweet,"",tweet_long_id,type,createdAt,replyTo,source,avatar,formattedTweet])
+                tweetstore.append([senderName,senderId,tweet,"",tweet_long_id,type,createdAt,replyTo,source,avatar,formattedTweet, True])
                 counter=counter+1
                 
                 
